=================================
Update of the jQuery UI libraries
=================================

1. Download the new jQuery-UI packages
2. Unzip the query-ui-*<version>*.custom.zip (in a empty directory)
3. copy the file **js/jquery-ui-*<version>*.custom.min.js** to
   **_GTW/media/js/jquery-ui.min.js**
4. copy the file **development-bundle/ui/jquery-ui-*<version>*.custom.js**
   to **_GTW/media/js/jquery-ui.js**
5. copy the file **css/*<theme>*/jquery-ui-*<version>*.custom.css** to
   to **_GTW/media/css/jquery-ui.css**
6. delete the **ui-\*** file from **_GTW/media/css/images**
6. copy the image files from **css/*<theme>*/images** to
   *_GTW/media/css/images**
